@@ -7,6 +7,7 @@ Don't use this for production code, it's a proof of concept.
 import openai
 import re
 import inspect
+import os
 
 class AIGremlin:
     def __init__(
@@ -33,6 +34,7 @@ class AIGremlin:
         self.temperature_escalation = temperature_escalation
         self.instructions = instructions
         self.functions = {}
+        self.function_iterations = {}
 
     def prompt_format(self, error, func, *args, **kwargs):
         """The prompt to OpenAI for error correcting the error. """
@@ -58,8 +60,6 @@ class AIGremlin:
             temperature=temperature,
             max_tokens=int(len(prompt) * 2),
         )
-        if self.verbose:
-            print(response.choices[0].text)
         return {
             "response": response.choices[0].text,
             "tokens": response.usage.total_tokens,
@@ -73,6 +73,8 @@ class AIGremlin:
     def update_temperature(self):
         if((self.temperature + self.temperature_escalation) < 1.0):
             self.temperature += self.temperature_escalation
+            if self.verbose and self.temperature_escalation > 0:
+                print(f"Temperature changed {self.temperature}")
 
     def ai_backstop(self, func):
         """
@@ -87,10 +89,12 @@ class AIGremlin:
             self.namespace = func.__globals__
             self.iterations = 0
             self.temperature = self.default_temperature
+            self.function_iterations[func.__name__] = 1
 
         except Exception as e:
             # Dynamically executed code cannot be inspected, so we need to get the source code from a dictionary.
             source_code = self.functions[func.__name__]
+            self.function_iterations[func.__name__] += 1
 
         def wrapper(*args, **kwargs):
             try:
@@ -100,7 +104,7 @@ class AIGremlin:
             except Exception as e:
                 if self.iterations > self.max_iterations:
                     print(
-                        f"{self.iterations} iterations and {self.tokens} tokens used, stopping"
+                        f"{self.iterations} iterations and {self.tokens} tokens used, stopping..."
                     )
                     return
                 self.iterations += 1
@@ -113,13 +117,14 @@ class AIGremlin:
                 self.functions[func.__name__] = response["response"]
                 self.tokens += response["tokens"]
 
-                print("Local code failed, using AI code")
-                print("Error was: ", e)
+                print("Local code failed with error: ", e)
+                print("Trying AI fix no:", self.iterations)
                 if self.verbose:
-                    print("Iteration: ", self.iterations)
                     print(
                     f"{response['tokens']} tokens used, total: {self.tokens} tokens used of a max of {self.max_tokens}")
-                print("Changing function to ", self.functions[func.__name__])
+                    iter = f'{func.__name__} v.{self.function_iterations[func.__name__]}'
+                    print_separator(iter)
+                    print(self.functions[func.__name__])
 
                 exec(self.functions[func.__name__], self.namespace)
                 new_function = self.namespace[func.__name__]
@@ -127,3 +132,15 @@ class AIGremlin:
                 return result
 
         return wrapper
+
+def print_separator(text='', char='-'):
+    """ Print a separator line with a text on the left side."""
+    try:
+        # Get the terminal width, if supported by the platform
+        term_width = os.get_terminal_size().columns
+    except (OSError, AttributeError):
+        # Fallback to a default width if the platform doesn't support it
+        term_width = 80
+
+    num_chars = term_width - len(text) - 1
+    print(f"{text} {char * num_chars}")
